@@ -18,6 +18,8 @@
 #include <QImage>
 #include <QObject>
 #include <memory>
+#include "rclcpp/clock.hpp"
+#include "rclcpp/duration.hpp"
 
 namespace rqt_image_overlay
 {
@@ -30,8 +32,11 @@ class Compositor : public QObject
 
 public:
   Compositor(
-    const ImageManager & imageManager, const OverlayManager & overlayManager,
-    float frequency);
+    const ImageManager & imageManager, const OverlayManager & overlayManager, float frequency);
+
+  // Thread safe setter/getter for window
+  void setWindow(const rclcpp::Duration & window);
+  rclcpp::Duration getWindow() const;
 
   void setCallableSetImage(std::function<void(std::shared_ptr<QImage>)> setImage);
 
@@ -43,6 +48,13 @@ private:
   const OverlayManager & overlayManager;
 
   std::function<void(std::shared_ptr<QImage>)> setImage;
+
+  // Wait window for collecting messages before composing image.
+  // To access this value, use the getWindow() method to ensure thread-safety, even from within
+  // this class.
+  std::shared_ptr<rclcpp::Duration> window_;
+
+  rclcpp::Clock systemClock{RCL_SYSTEM_TIME};
 };
 
 }  // namespace rqt_image_overlay
